@@ -119,4 +119,4 @@ templates = (
   ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS2ID2', True, 'itk::Image< unsigned short,2 >, itk::Image< double,2 >'),
   ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS3ID3', True, 'itk::Image< unsigned short,3 >, itk::Image< double,3 >'),
 )
-snake_case_functions = ('danielsson_distance_map_image_filter', 'contour_mean_distance_image_filter', 'iso_contour_distance_image_filter', 'signed_danielsson_distance_map_image_filter', 'directed_hausdorff_distance_image_filter', 'approximate_signed_distance_map_image_filter', 'fast_chamfer_distance_image_filter', 'signed_maurer_distance_map_image_filter', 'hausdorff_distance_image_filter', 'contour_directed_mean_distance_image_filter', )
+snake_case_functions = ('approximate_signed_distance_map_image_filter', 'signed_danielsson_distance_map_image_filter', 'danielsson_distance_map_image_filter', 'signed_maurer_distance_map_image_filter', 'contour_directed_mean_distance_image_filter', 'contour_mean_distance_image_filter', 'hausdorff_distance_image_filter', 'directed_hausdorff_distance_image_filter', 'fast_chamfer_distance_image_filter', 'iso_contour_distance_image_filter', )
