@@ -138,4 +138,4 @@ templates = (
   ('ZeroCrossingImageFilter', 'itk::ZeroCrossingImageFilter', 'itkZeroCrossingImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
   ('ZeroCrossingImageFilter', 'itk::ZeroCrossingImageFilter', 'itkZeroCrossingImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
 )
-snake_case_functions = ('discrete_gaussian_derivative_image_filter', 'derivative_image_filter', 'image_to_mesh_filter', 'zero_crossing_based_edge_detection_image_filter', 'laplacian_image_filter', 'zero_crossing_image_filter', 'laplacian_sharpening_image_filter', 'hessian_recursive_gaussian_image_filter', 'sobel_edge_detection_image_filter', 'gradient_vector_flow_image_filter', 'canny_edge_detection_image_filter', 'hough_transform2_d_lines_image_filter', 'laplacian_recursive_gaussian_image_filter', 'multi_scale_hessian_based_measure_image_filter', 'hessian3_d_to_vesselness_measure_image_filter', 'hessian_to_objectness_measure_image_filter', 'simple_contour_extractor_image_filter', 'unsharp_mask_image_filter', 'mesh_source', 'mask_feature_point_selection_filter', 'bilateral_image_filter', 'hough_transform2_d_circles_image_filter', )
+snake_case_functions = ('mask_feature_point_selection_filter', 'hough_transform2_d_circles_image_filter', 'sobel_edge_detection_image_filter', 'gradient_vector_flow_image_filter', 'derivative_image_filter', 'discrete_gaussian_derivative_image_filter', 'hessian3_d_to_vesselness_measure_image_filter', 'simple_contour_extractor_image_filter', 'mesh_source', 'hessian_recursive_gaussian_image_filter', 'laplacian_recursive_gaussian_image_filter', 'image_to_mesh_filter', 'canny_edge_detection_image_filter', 'hessian_to_objectness_measure_image_filter', 'laplacian_image_filter', 'laplacian_sharpening_image_filter', 'zero_crossing_based_edge_detection_image_filter', 'zero_crossing_image_filter', 'bilateral_image_filter', 'hough_transform2_d_lines_image_filter', 'unsharp_mask_image_filter', 'multi_scale_hessian_based_measure_image_filter', )
