@@ -453,4 +453,4 @@ templates = (
   ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
   ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
 )
-snake_case_functions = ('wrap_pad_image_filter', 'warp_image_filter', 'bin_shrink_image_filter', 'tile_image_filter', 'paste_image_filter', 'mirror_pad_image_filter', 'interpolate_image_filter', 'permute_axes_image_filter', 'b_spline_upsample_image_filter', 'constant_pad_image_filter', 'flip_image_filter', 'pad_image_filter', 'expand_image_filter', 'pad_image_filter_base', 'crop_image_filter', 'resample_image_filter', 'orient_image_filter', 'slice_by_slice_image_filter', 'region_of_interest_image_filter', 'b_spline_resample_image_filter_base', 'shrink_image_filter', 'change_information_image_filter', 'cyclic_shift_image_filter', 'zero_flux_neumann_pad_image_filter', 'b_spline_downsample_image_filter', )
+snake_case_functions = ('pad_image_filter_base', 'crop_image_filter', 'orient_image_filter', 'cyclic_shift_image_filter', 'b_spline_upsample_image_filter', 'zero_flux_neumann_pad_image_filter', 'change_information_image_filter', 'permute_axes_image_filter', 'wrap_pad_image_filter', 'b_spline_downsample_image_filter', 'shrink_image_filter', 'pad_image_filter', 'interpolate_image_filter', 'paste_image_filter', 'tile_image_filter', 'resample_image_filter', 'flip_image_filter', 'slice_by_slice_image_filter', 'bin_shrink_image_filter', 'mirror_pad_image_filter', 'constant_pad_image_filter', 'b_spline_resample_image_filter_base', 'warp_image_filter', 'region_of_interest_image_filter', 'expand_image_filter', )
