@@ -214,4 +214,4 @@ templates = (
   ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
   ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterID3ID2', True, 'itk::Image< double,3 >,itk::Image< double,2 >'),
 )
-snake_case_functions = ('median_projection_image_filter', 'image_pca_shape_model_estimator', 'accumulate_image_filter', 'label_statistics_image_filter', 'minimum_projection_image_filter', 'sum_projection_image_filter', 'minimum_maximum_image_filter', 'binary_projection_image_filter', 'maximum_projection_image_filter', 'projection_image_filter', 'standard_deviation_projection_image_filter', 'statistics_image_filter', 'mean_projection_image_filter', 'image_shape_model_estimator_base', )
+snake_case_functions = ('label_statistics_image_filter', 'image_shape_model_estimator_base', 'binary_projection_image_filter', 'sum_projection_image_filter', 'median_projection_image_filter', 'standard_deviation_projection_image_filter', 'mean_projection_image_filter', 'image_pca_shape_model_estimator', 'minimum_maximum_image_filter', 'statistics_image_filter', 'maximum_projection_image_filter', 'minimum_projection_image_filter', 'projection_image_filter', 'accumulate_image_filter', )
