@@ -312,4 +312,4 @@ templates = (
   ('WeightedCentroidKdTreeGenerator', 'itk::Statistics::WeightedCentroidKdTreeGenerator', 'itkWeightedCentroidKdTreeGeneratorLSVF2', True, 'itk::Statistics::ListSample< itk::Vector< float,2 > >'),
   ('WeightedCentroidKdTreeGenerator', 'itk::Statistics::WeightedCentroidKdTreeGenerator', 'itkWeightedCentroidKdTreeGeneratorLSVF3', True, 'itk::Statistics::ListSample< itk::Vector< float,3 > >'),
 )
-snake_case_functions = ('histogram_to_intensity_image_filter', 'masked_image_to_histogram_filter', 'histogram_to_run_length_features_filter', 'image_to_histogram_filter', 'histogram_to_texture_features_filter', 'histogram_to_entropy_image_filter', 'scalar_image_to_run_length_features_filter', 'histogram_to_image_filter', 'scalar_image_to_texture_features_filter', 'histogram_to_log_probability_image_filter', 'scalar_image_to_run_length_matrix_filter', 'scalar_image_to_cooccurrence_matrix_filter', 'histogram_to_probability_image_filter', )
+snake_case_functions = ('histogram_to_texture_features_filter', 'histogram_to_log_probability_image_filter', 'histogram_to_run_length_features_filter', 'scalar_image_to_run_length_matrix_filter', 'scalar_image_to_texture_features_filter', 'histogram_to_intensity_image_filter', 'scalar_image_to_cooccurrence_matrix_filter', 'image_to_histogram_filter', 'scalar_image_to_run_length_features_filter', 'histogram_to_entropy_image_filter', 'histogram_to_image_filter', 'masked_image_to_histogram_filter', 'histogram_to_probability_image_filter', )
